v0.0.3
======

Fix: Run aflak as module (with `python -m aflak`)

New:

- Include some unit tests
- Include units in waveform axes, read from loaded FITS files


v0.0.2
======

Fix: Use logarithmic scale on brightness histograms


v0.0.1
======

Very first version released on PyPI. Can only open FITS files and visualize
FLUX and WAVE data.
